// Copyright © 2020 Finn Herzfeld <finn@janky.solutions>
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

package cmd

import (
	"encoding/json"
	"log"
	"os"

	"github.com/spf13/cobra"

	"gitlab.com/signald/signald-go/signald/client-protocol/v1"
)

// listGroupsCmd represents the listGroups command
var listGroupsCmd = &cobra.Command{
	Use:   "list-groups",
	Short: "list of all the groups that the user is in.",
	Long:  `Prints a list of all groups the user is in to stdout.`,
	Run: func(cmd *cobra.Command, args []string) {
		go s.Listen(nil)
		req := v1.ListGroupsRequest{Account: username}
		resp, err := req.Submit(s)
		if err != nil {
			log.Fatal(err, "error communicating with signald")
		}
		err = json.NewEncoder(os.Stdout).Encode(resp)
		if err != nil {
			log.Fatal(err, "error encoding response to stdout")
		}
	},
}

func init() {
	RootCmd.AddCommand(listGroupsCmd)

	listGroupsCmd.Flags().StringVarP(&username, "username", "u", "", "The username of the account to use)")
	must(listGroupsCmd.MarkFlagRequired("username"))
}
